@@ -109,6 +109,7 @@ def recreate(ctx, config, machines):
 @pass_config
 @click.pass_context
 def up(ctx, config, machines, daemon):
+    from .lib_setup import _status
     if config.use_docker:
         from .lib_control_with_docker import up as lib_up
     else:
@@ -117,6 +118,8 @@ def up(ctx, config, machines, daemon):
     execute_script(
         config, config.files["after_up_script"], "Possible after up script here:"
     )
+    if daemon:
+        _status(config)
 
 
 @docker.command()
